#ifndef ColorList_h
#define ColorList_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ColorModel.h"
#include "Counter.h"
#include "TreeView.h"

#include <QAction>
#include <QGroupBox>
#include <QWidget>

class ColorList: public QGroupBox
{

    Q_OBJECT

    public:

    //* constructor
    explicit ColorList( QWidget* );

    //* add color to list
    void add( const Base::Color& color, bool select = true );

    //* model
    ColorModel& model()
    { return model_; }

    //* list
    TreeView& list() const
    { return *list_; }

    //* remove
    QAction& removeAction() const
    { return *removeAction_; }

    private Q_SLOTS:

    //* remove selected colors
    void _remove();

    //* update button state
    void _updateActions();

    private:

    //* install actions
    void _installActions();

    //* color model
    ColorModel model_;

    //* list
    TreeView* list_ = nullptr;

    //@name actions
    //@{

    //* remove action
    QAction* removeAction_ = nullptr;

    //@}

};

#endif
