#ifndef ColorSelectionFrame_h
#define ColorSelectionFrame_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"

#include <QPushButton>
#include <QSpinBox>
#include <QHash>

class LineEditor;

namespace Private
{
    class ColorWidget;
    class ColorDisplay;
};

//class ColorSelectionFrame:public QGroupBox, private Base::Counter<ColorSelectionFrame>
class ColorSelectionFrame:public QWidget, private Base::Counter<ColorSelectionFrame>
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* creator
    explicit ColorSelectionFrame( QWidget* parent );

    //*@name accessors
    //@{

    //* retrieve selected color
    const QColor& color() const
    { return color_; }

    //* color widget
    QAbstractButton& colorWidget() const;

    //@}

    //*@name actions
    //@{

    //* save action
    QAction& autoHideAction() const
    { return *autoHideAction_; }

    //* save action
    QAction& saveAction() const
    { return *saveAction_; }

    //@}

    public Q_SLOTS:

    //* sets selected color
    void setColor( QColor );

    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration();

    //* toggle auto hide
    void _toggleAutoHide( bool );

    //* update color from editor
    void _fromEditor( const QString& );

    //* update color from HSV editors
    void _fromHsv();

    //* update color from RGB editors
    void _fromRgb();

    private:

    //* update label
    void _updateLabel();

    //* install actions
    void _installActions();

    //* line editor id enumeration
    enum SpinBoxId
    {
        Hue,
        Saturation,
        Value,
        Red,
        Green,
        Blue,
        Alpha
    };

    //* internal line Editor to have matching ID
    class SpinBox: public QSpinBox
    {

        public:

        //* constructor
        explicit SpinBox( QWidget* parent, SpinBoxId id ):
            QSpinBox( parent ),
            id_( id )
        {}

        //* button ID
        SpinBoxId id() const
        { return id_; }

        private:

        //* button ID
        SpinBoxId id_;

    };

    //* true when values are being updated
    /** it is used to disable the callbacks when updating from one spinbox */
    bool locked_ = false;

    //* color widget
    Private::ColorWidget* colorWidget_ = nullptr;

    //* color display
    Private::ColorDisplay* colorDisplay_ = nullptr;

    //* the label where color and colorname are display
    LineEditor* editor_ = nullptr;

    //*@name actions
    //@{

    //* auto hide action
    QAction* autoHideAction_ = nullptr;

    //* save action
    QAction* saveAction_ = nullptr;

    //@}

    //* Editor map
    using SpinBoxMap = QHash< SpinBoxId, SpinBox* >;

    //* Editor map
    SpinBoxMap spinboxes_;

    //* current selected color
    QColor color_;

};

#endif
