#ifndef MainWindow_h
#define MainWindow_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseMainWindow.h"
#include "Counter.h"
#include "Debug.h"

#include <QCloseEvent>
#include <QModelIndex>

class ColorList;
class ColorSelectionFrame;

//* color picker dialog
class MainWindow: public BaseMainWindow
{

    Q_OBJECT

    public:

    //* constructor
    explicit MainWindow( QWidget* = nullptr);

    //*@name accessors
    //@{

    //* color selection frame
    ColorSelectionFrame& colorSelectionFrame() const
    { return *selectionFrame_; }

    //@}

    //*@name actions
    //@{

    //* toggle list
    QAction& toggleListAction() const
    { return *toggleListAction_; }

    //@}

    protected:

    //* close event
    void closeEvent( QCloseEvent* ) override;

    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration();

    //* load colors from file
    void _read();

    //* write colors to file
    void _write();

    //* add current color in list
    void _add();

    //* select color from list
    void _selectFromList( const QModelIndex & );

    //* show/hide recent colors
    void _toggleShowList( bool );

    private:

    //* install actions
    void _installActions();

    //* color list
    ColorList* list_ = nullptr;

    //* frame to display current color
    ColorSelectionFrame* selectionFrame_ = nullptr;

    //@name actions
    //@{

    //* toggle list
    QAction* toggleListAction_ = nullptr;

    //@}

};

#endif
